KMSubtractionEvaluateMatch: Evaluate of the quality of 'KMSubtractionMatch' matching

Description Usage Arguments Examples

View source: R/KMSubtractionEvaluateMatch.R

Description

This function evaluates of the quality of matching by inspecting Empirical cumulative distribution functions and the Kolmogorov−Smirnov Test of follow-up times between matched pairs as well as with Bland-Altman plots to explore discrepancies between matched pairs.

Usage

1

Arguments

df_match

A dataframe (data) from KMSubtractionMatch() containing time-to-event data of the matched cohorts "time" and "status"; the curve it originates from "curve"; as well as the "matchid".

Examples

1
2
3
4
5
6
data(cancer)
df_overall=colon
df_subgroup=colon[1:200,]
match=KMSubtractionMatch(df_overall, df_subgroup, matching="bipartite")

KMSubtractionEvaluateMatch(df_match=match$data)

josephjzhao/KMSubtraction documentation built on Jan. 25, 2022, 6:35 p.m.