getxycoordinates: Retrieve xy coordinates from time-to-event survival data.

Description Usage Arguments Examples

View source: R/getxycoordinates.R

Description

This function converts a Kaplan Meier curve into xy coordinates. It returns a dataframe containing xy coordinates of the Kaplan Meier curve created with time-to-event data from the dataframe provided.

Usage

1
getxycoordinates(df, label = 1)

Arguments

df

The dataframe containing time and status data required to create the Kaplan Meier curve.

label

Name the curve that will be exported. Useful in providing a unique id in parallel processing. Not needed in serial processing.

Examples

1
2

josephjzhao/KMSubtraction documentation built on Jan. 25, 2022, 6:35 p.m.