Description Usage Arguments Examples
View source: R/getxycoordinates.R
This function converts a Kaplan Meier curve into xy coordinates. It returns a dataframe containing xy coordinates of the Kaplan Meier curve created with time-to-event data from the dataframe provided.
1 | getxycoordinates(df, label = 1)
|
df |
The dataframe containing time and status data required to create the Kaplan Meier curve. |
label |
Name the curve that will be exported. Useful in providing a unique id in parallel processing. Not needed in serial processing. |
1 2 | data(cancer)
getxycoordinates(colon)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.